@@ -427,6 +427,7 @@ gnome_calendar_constructed (GObject *object)
 	calendar_view = e_day_view_new (model);
 	e_calendar_view_set_calendar (calendar_view, gcal);
 	gcal->priv->views[GNOME_CAL_DAY_VIEW] = calendar_view;
+	g_object_ref_sink (calendar_view);
 
 	g_signal_connect_swapped (
 		calendar_view, "selection-changed",
@@ -438,6 +439,7 @@ gnome_calendar_constructed (GObject *object)
 	e_day_view_set_days_shown (E_DAY_VIEW (calendar_view), 5);
 	e_calendar_view_set_calendar (calendar_view, gcal);
 	gcal->priv->views[GNOME_CAL_WORK_WEEK_VIEW] = calendar_view;
+	g_object_ref_sink (calendar_view);
 
 	g_signal_connect_swapped (
 		calendar_view, "notify::working-days",
@@ -447,6 +449,7 @@ gnome_calendar_constructed (GObject *object)
 	calendar_view = e_week_view_new (model);
 	e_calendar_view_set_calendar (calendar_view, gcal);
 	gcal->priv->views[GNOME_CAL_WEEK_VIEW] = calendar_view;
+	g_object_ref_sink (calendar_view);
 
 	g_signal_connect_swapped (
 		calendar_view, "selection-changed",
@@ -464,6 +467,7 @@ gnome_calendar_constructed (GObject *object)
 	e_week_view_set_weeks_shown (E_WEEK_VIEW (calendar_view), 6);
 	e_calendar_view_set_calendar (calendar_view, gcal);
 	gcal->priv->views[GNOME_CAL_MONTH_VIEW] = calendar_view;
+	g_object_ref_sink (calendar_view);
 
 	g_signal_connect_swapped (
 		calendar_view, "selection-changed",
@@ -479,6 +483,7 @@ gnome_calendar_constructed (GObject *object)
 	calendar_view = e_cal_list_view_new (model);
 	e_calendar_view_set_calendar (calendar_view, gcal);
 	gcal->priv->views[GNOME_CAL_LIST_VIEW] = calendar_view;
+	g_object_ref_sink (calendar_view);
 
 	g_signal_connect_swapped (
 		calendar_view, "selection-changed",
@@ -1009,11 +1014,18 @@ adjust_e_cal_view_sexp (GnomeCalendar *gcal, const gchar *sexp)
 	start = isodate_from_time_t (start_time);
 	end = isodate_from_time_t (end_time);
 
-	new_sexp = g_strdup_printf ("(and (occur-in-time-range? (make-time \"%s\")"
-				    "                           (make-time \"%s\"))"
-				    "     %s)",
-				    start, end,
-				    sexp);
+	if (sexp) {
+		new_sexp = g_strdup_printf ("(and (occur-in-time-range? (make-time \"%s\")"
+				"                           (make-time \"%s\"))"
+				"     %s)",
+				start, end,
+				sexp);
+	} else {
+		new_sexp = g_strdup_printf ("(occur-in-time-range? (make-time \"%s\")"
+				"                     (make-time \"%s\"))",
+				start, end);
+	}
+
 	g_free (start);
 	g_free (end);
 
@@ -1067,8 +1079,6 @@ update_query_async (struct _date_query_msg *msg)
 
 	real_sexp = adjust_e_cal_view_sexp (gcal, priv->sexp);
 	if (!real_sexp) {
-		g_object_unref (msg->gcal);
-		g_slice_free (struct _date_query_msg, msg);
 		return; /* No time range is set, so don't start a query */
 	}
 
@@ -1125,9 +1135,15 @@ try_again:
 	/* free memory */
 	g_free (real_sexp);
 	update_todo_view (gcal);
+}
 
+static gboolean
+update_query_done (struct _date_query_msg *msg)
+{
 	g_object_unref (msg->gcal);
 	g_slice_free (struct _date_query_msg, msg);
+
+	return FALSE;
 }
 
 /* Restarts a query for the date navigator in the calendar */
@@ -1142,7 +1158,7 @@ gnome_calendar_update_query (GnomeCalendar *gcal)
 
 	msg = g_slice_new0 (struct _date_query_msg);
 	msg->header.func = (MessageFunc) update_query_async;
-	msg->header.done = NULL;
+	msg->header.done = (GSourceFunc) update_query_done;
 	msg->gcal = g_object_ref (gcal);
 
 	message_push ((Message *) msg);
@@ -1483,6 +1499,7 @@ gnome_calendar_do_dispose (GObject *object)
 	GList *l;
 	GnomeCalendar *gcal;
 	GnomeCalendarPrivate *priv;
+	gint ii;
 
 	g_return_if_fail (object != NULL);
 	g_return_if_fail (GNOME_IS_CALENDAR (object));
@@ -1499,6 +1516,13 @@ gnome_calendar_do_dispose (GObject *object)
 		priv->model = NULL;
 	}
 
+	for (ii = 0; ii < GNOME_CAL_LAST_VIEW; ii++) {
+		if (priv->views[ii] != NULL) {
+			g_object_unref (priv->views[ii]);
+			priv->views[ii] = NULL;
+		}
+	}
+
 	for (l = priv->notifications; l; l = l->next)
 		calendar_config_remove_notification (GPOINTER_TO_UINT (l->data));
 	g_list_free (priv->notifications);
