@@ -331,7 +331,9 @@ part_combobox_changed (GtkComboBox *combobox, struct _part_data *data)
 	gint index, i;
 
 	index = gtk_combo_box_get_active (combobox);
-	for (i = 0, part = em_filter_context_next_action (data->f, part); part && i < index; i++, part = em_filter_context_next_action (data->f, part)) {
+	for (i = 0, part = em_filter_context_next_action (data->f, part);
+		part && i < index;
+		i++, part = em_filter_context_next_action (data->f, part)) {
 		/* traverse until reached index */
 	}
 
@@ -373,6 +375,9 @@ get_rule_part_widget(EMFilterContext *f, EFilterPart *newpart, EFilterRule *fr)
 	data->part = newpart;
 
 	hbox = gtk_hbox_new(FALSE, 0);
+	/* only set to automatically clean up the memory and for less_parts */
+	g_object_set_data_full ((GObject *) hbox, "data", data, g_free);
+
 	p = e_filter_part_get_widget(newpart);
 
 	data->partwidget = p;
@@ -412,6 +417,7 @@ less_parts(GtkWidget *button, struct _rule_data *data)
 {
 	EFilterPart *part;
 	GtkWidget *rule;
+	struct _part_data *part_data;
 	GList *l;
 
 	l =((EMFilterRule *)data->fr)->actions;
@@ -419,7 +425,11 @@ less_parts(GtkWidget *button, struct _rule_data *data)
 		return;
 
 	rule = g_object_get_data((GObject *)button, "rule");
-	part = g_object_get_data((GObject *)rule, "part");
+	part_data = g_object_get_data ((GObject *) rule, "data");
+
+	g_return_if_fail (part_data != NULL);
+
+	part = part_data->part;
 
 	/* remove the part from the list */
 	em_filter_rule_remove_action((EMFilterRule *)data->fr, part);
@@ -440,7 +450,6 @@ attach_rule(GtkWidget *rule, struct _rule_data *data, EFilterPart *part, gint ro
 
 	remove = gtk_button_new_from_stock(GTK_STOCK_REMOVE);
 	g_object_set_data((GObject *)remove, "rule", rule);
-	g_object_set_data((GObject *)rule, "part", part);
 	/*gtk_button_set_relief(GTK_BUTTON(remove), GTK_RELIEF_NONE);*/
 	g_signal_connect(remove, "clicked", G_CALLBACK(less_parts), data);
 	gtk_table_attach(GTK_TABLE(data->parts), remove, 1, 2, row, row + 1,
@@ -456,7 +465,7 @@ do_grab_focus_cb (GtkWidget *widget, gpointer data)
 	if (*done)
 		return;
 
-	if (widget && GTK_WIDGET_CAN_FOCUS (widget)) {
+	if (widget && gtk_widget_get_can_focus (widget)) {
 		*done = TRUE;
 		gtk_widget_grab_focus (widget);
 	}
@@ -471,13 +480,13 @@ more_parts(GtkWidget *button, struct _rule_data *data)
 	new = em_filter_context_next_action((EMFilterContext *)data->f, NULL);
 	if (new) {
 		GtkWidget *w;
-		guint16 rows;
+		guint rows;
 
 		new = e_filter_part_clone(new);
 		em_filter_rule_add_action((EMFilterRule *)data->fr, new);
 		w = get_rule_part_widget(data->f, new, data->fr);
 
-		rows = GTK_TABLE(data->parts)->nrows;
+		g_object_get (data->parts, "n-rows", &rows, NULL);
 		gtk_table_resize(GTK_TABLE(data->parts), rows + 1, 2);
 		attach_rule(w, data, new, rows);
 
@@ -494,9 +503,12 @@ more_parts(GtkWidget *button, struct _rule_data *data)
 			GtkAdjustment *adjustment;
 
 			adjustment = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (w));
-			if (adjustment)
-				gtk_adjustment_set_value (adjustment, adjustment->upper);
+			if (adjustment) {
+				gdouble upper;
 
+				upper = gtk_adjustment_get_upper (adjustment);
+				gtk_adjustment_set_value (adjustment, upper);
+			}
 		}
 	}
 }
@@ -544,11 +556,15 @@ get_widget(EFilterRule *fr, ERuleContext *rc)
 	data->fr = fr;
 	data->parts = parts;
 
+	/* only set to automatically clean up the memory */
+	g_object_set_data_full ((GObject *) hbox, "data", data, g_free);
+
 	hbox = gtk_hbox_new(FALSE, 3);
 
 	add = gtk_button_new_with_mnemonic (_("Add Ac_tion"));
-	gtk_button_set_image (GTK_BUTTON (add), gtk_image_new_from_stock (GTK_STOCK_ADD, GTK_ICON_SIZE_BUTTON));
-	/* gtk_button_set_relief(GTK_BUTTON(add), GTK_RELIEF_NONE); */
+	gtk_button_set_image (
+		GTK_BUTTON (add), gtk_image_new_from_stock (
+		GTK_STOCK_ADD, GTK_ICON_SIZE_BUTTON));
 	g_signal_connect(add, "clicked", G_CALLBACK(more_parts), data);
 	gtk_box_pack_start(GTK_BOX(hbox), add, FALSE, FALSE, 0);
 
