@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -25,6 +25,7 @@
 #include <config.h>
 #endif
 
+#include <errno.h>
 #include <string.h>
 #include <sys/types.h>
 #include <sys/types.h>
@@ -34,111 +35,27 @@
 
 #include <glib.h>
 #include <glib/gstdio.h>
-
-#include <gmodule.h>
-#include <libgnome/gnome-util.h>
 #include <glib/gi18n.h>
-#include <camel/camel-folder.h>
-#include <camel/camel-store.h>
-#include <camel/camel-mime-message.h>
-#include <camel/camel-mime-parser.h>
-#include <camel/camel-exception.h>
-#include <camel/camel-stream-mem.h>
 
 #include "e-util/e-util-private.h"
+#include "shell/e-shell-backend.h"
 
-#include "mail/mail-mt.h"
-#include "mail/mail-component.h"
-#include "mail/mail-tools.h"
+#include "mail-mt.h"
+#include "mail-tools.h"
+#include "e-mail-local.h"
+#include "mail-session.h"
 
 #include "mail-importer.h"
 
-/**
- * mail_importer_make_local_folder:
- * @folderpath:
- *
- * Check a local folder exists at path @folderpath, and if not, create it.
- *
- * Return value: The physical uri of the folder, or NULL if the folder did
- * not exist and could not be created.
- **/
-char *
-mail_importer_make_local_folder(const char *folderpath)
-{
-	return g_strdup_printf("mbox:/home/notzed/.evolution/mail/local/%s", folderpath);
-}
-
-/**
- * mail_importer_add_line:
- * importer: A MailImporter structure.
- * str: Next line of the mbox.
- * finished: TRUE if @str is the last line of the message.
- *
- * Adds lines to the message until it is finished, and then adds
- * the complete message to the folder.
- */
-void
-mail_importer_add_line (MailImporter *importer,
-			const char *str,
-			gboolean finished)
-{
-	CamelMimeMessage *msg;
-	CamelMessageInfo *info;
-	CamelException *ex;
-
-	if (importer->mstream == NULL)
-		importer->mstream = CAMEL_STREAM_MEM (camel_stream_mem_new ());
-
-	camel_stream_write (CAMEL_STREAM (importer->mstream), str,  strlen (str));
-
-	if (finished == FALSE)
-		return;
-
-	camel_stream_reset (CAMEL_STREAM (importer->mstream));
-	info = camel_message_info_new(NULL);
-	camel_message_info_set_flags(info, CAMEL_MESSAGE_SEEN, ~0);
-
-	msg = camel_mime_message_new ();
-	camel_data_wrapper_construct_from_stream (CAMEL_DATA_WRAPPER (msg),
-						  CAMEL_STREAM (importer->mstream));
-
-	camel_object_unref (importer->mstream);
-	importer->mstream = NULL;
-
-	ex = camel_exception_new ();
-	camel_folder_append_message (importer->folder, msg, info, NULL, ex);
-	camel_object_unref (msg);
-
-	camel_exception_free (ex);
-	camel_message_info_free(info);
-}
-
-struct _BonoboObject *mail_importer_factory_cb(struct _BonoboGenericFactory *factory, const char *iid, void *data)
-{
-#if 0
-	if (strcmp(iid, ELM_INTELLIGENT_IMPORTER_IID) == 0)
-		return elm_intelligent_importer_new();
-	else if (strcmp(iid, PINE_INTELLIGENT_IMPORTER_IID) == 0)
-		return pine_intelligent_importer_new();
-	else if (strcmp(iid, NETSCAPE_INTELLIGENT_IMPORTER_IID) == 0)
-		return netscape_intelligent_importer_new();
-	else if (strcmp(iid, MBOX_IMPORTER_IID) == 0)
-		return mbox_importer_new();
-	else if (strcmp(iid, OUTLOOK_IMPORTER_IID) == 0)
-		return outlook_importer_new();
-#endif
-	return NULL;
-}
-
 struct _import_mbox_msg {
 	MailMsg base;
 
-	char *path;
-	char *uri;
+	gchar *path;
+	gchar *uri;
 	CamelOperation *cancel;
 
-	void (*done)(void *data, CamelException *ex);
-	void *done_data;
+	void (*done)(gpointer data, GError **error);
+	gpointer done_data;
 };
 
 static gchar *
@@ -148,7 +65,7 @@ import_mbox_desc (struct _import_mbox_msg *m)
 }
 
 static struct {
-	char tag;
+	gchar tag;
 	guint32 mozflag;
 	guint32 flag;
 } status_flags[] = {
@@ -159,15 +76,15 @@ static struct {
 };
 
 static guint32
-decode_status(const char *status)
+decode_status(const gchar *status)
 {
-	const char *p;
+	const gchar *p;
 	guint32 flags = 0;
-	int i;
+	gint i;
 
 	p = status;
 	while ((*p++)) {
-		for (i=0;i<sizeof(status_flags)/sizeof(status_flags[0]);i++)
+		for (i = 0; i < G_N_ELEMENTS (status_flags); i++)
 			if (status_flags[i].tag == *p)
 				flags |= status_flags[i].flag;
 	}
@@ -176,13 +93,13 @@ decode_status(const char *status)
 }
 
 static guint32
-decode_mozilla_status(const char *tmp)
+decode_mozilla_status(const gchar *tmp)
 {
 	unsigned long status = strtoul(tmp, NULL, 16);
 	guint32 flags = 0;
-	int i;
+	gint i;
 
-	for (i=0;i<sizeof(status_flags)/sizeof(status_flags[0]);i++)
+	for (i = 0; i < G_N_ELEMENTS (status_flags); i++)
 		if (status_flags[i].mozflag & status)
 			flags |= status_flags[i].flag;
 	return flags;
@@ -194,7 +111,7 @@ import_mbox_exec (struct _import_mbox_msg *m)
 	CamelFolder *folder;
 	CamelMimeParser *mp = NULL;
 	struct stat st;
-	int fd;
+	gint fd;
 	CamelMessageInfo *info;
 
 	if (g_stat(m->path, &st) == -1) {
@@ -203,9 +120,10 @@ import_mbox_exec (struct _import_mbox_msg *m)
 	}
 
 	if (m->uri == NULL || m->uri[0] == 0)
-		folder = mail_component_get_folder(NULL, MAIL_COMPONENT_FOLDER_INBOX);
+		folder = e_mail_local_get_folder (E_MAIL_FOLDER_INBOX);
 	else
-		folder = mail_tool_uri_to_folder(m->uri, CAMEL_STORE_FOLDER_CREATE, &m->base.ex);
+		folder = mail_tool_uri_to_folder (
+			m->uri, CAMEL_STORE_FOLDER_CREATE, &m->base.error);
 
 	if (folder == NULL)
 		return;
@@ -228,22 +146,24 @@ import_mbox_exec (struct _import_mbox_msg *m)
 		if (m->cancel)
 			oldcancel = camel_operation_register(m->cancel);
 
-		camel_operation_start(NULL, _("Importing `%s'"), folder->full_name);
+		camel_operation_start (
+			NULL, _("Importing '%s'"),
+			camel_folder_get_full_name (folder));
 		camel_folder_freeze(folder);
 		while (camel_mime_parser_step(mp, NULL, NULL) == CAMEL_MIME_PARSER_STATE_FROM) {
 			CamelMimeMessage *msg;
-			const char *tmp;
-			int pc = 0;
+			const gchar *tmp;
+			gint pc = 0;
 			guint32 flags = 0;
 
 			if (st.st_size > 0)
-				pc = (int)(100.0 * ((double)camel_mime_parser_tell(mp) / (double)st.st_size));
+				pc = (gint)(100.0 * ((double)camel_mime_parser_tell(mp) / (double)st.st_size));
 			camel_operation_progress(NULL, pc);
 
 			msg = camel_mime_message_new();
-			if (camel_mime_part_construct_from_parser((CamelMimePart *)msg, mp) == -1) {
+			if (camel_mime_part_construct_from_parser((CamelMimePart *)msg, mp, NULL) == -1) {
 				/* set exception? */
-				camel_object_unref(msg);
+				g_object_unref (msg);
 				break;
 			}
 
@@ -260,11 +180,12 @@ import_mbox_exec (struct _import_mbox_msg *m)
 				flags |= decode_status(tmp);
 
 			camel_message_info_set_flags(info, flags, ~0);
-			camel_folder_append_message(folder, msg, info, NULL, &m->base.ex);
+			camel_folder_append_message (
+				folder, msg, info, NULL, &m->base.error);
 			camel_message_info_free(info);
-			camel_object_unref(msg);
+			g_object_unref (msg);
 
-			if (camel_exception_is_set(&m->base.ex))
+			if (m->base.error != NULL)
 				break;
 
 			camel_mime_parser_step(mp, NULL, NULL);
@@ -276,18 +197,18 @@ import_mbox_exec (struct _import_mbox_msg *m)
 		if (m->cancel)
 			camel_operation_register(oldcancel);
 	fail2:
-		camel_object_unref(mp);
+		g_object_unref (mp);
 	}
 fail1:
 	camel_folder_sync(folder, FALSE, NULL);
-	camel_object_unref(folder);
+	g_object_unref (folder);
 }
 
 static void
 import_mbox_done (struct _import_mbox_msg *m)
 {
 	if (m->done)
-		m->done(m->done_data, &m->base.ex);
+		m->done(m->done_data, &m->base.error);
 }
 
 static void
@@ -307,11 +228,11 @@ static MailMsgInfo import_mbox_info = {
 	(MailMsgFreeFunc) import_mbox_free
 };
 
-int
-mail_importer_import_mbox(const char *path, const char *folderuri, CamelOperation *cancel, void (*done)(void *data, CamelException *), void *data)
+gint
+mail_importer_import_mbox(const gchar *path, const gchar *folderuri, CamelOperation *cancel, void (*done)(gpointer data, GError **), gpointer data)
 {
 	struct _import_mbox_msg *m;
-	int id;
+	gint id;
 
 	m = mail_msg_new(&import_mbox_info);
 	m->path = g_strdup(path);
@@ -330,7 +251,7 @@ mail_importer_import_mbox(const char *path, const char *folderuri, CamelOperatio
 }
 
 void
-mail_importer_import_mbox_sync(const char *path, const char *folderuri, CamelOperation *cancel)
+mail_importer_import_mbox_sync(const gchar *path, const gchar *folderuri, CamelOperation *cancel)
 {
 	struct _import_mbox_msg *m;
 
@@ -355,18 +276,21 @@ struct _import_folders_data {
 };
 
 static void
-import_folders_rec(struct _import_folders_data *m, const char *filepath, const char *folderparent)
+import_folders_rec(struct _import_folders_data *m, const gchar *filepath, const gchar *folderparent)
 {
 	GDir *dir;
-	const char *d;
+	const gchar *d;
 	struct stat st;
-	char *filefull, *foldersub, *uri, *utf8_filename;
-	const char *folder;
+	const gchar *data_dir;
+	gchar *filefull, *foldersub, *uri, *utf8_filename;
+	const gchar *folder;
 
 	dir = g_dir_open(filepath, 0, NULL);
- 	if (dir == NULL)
+	if (dir == NULL)
 		return;
 
+	data_dir = mail_session_get_data_dir ();
+
 	utf8_filename = g_filename_to_utf8 (filepath, -1, NULL, NULL, NULL);
 	camel_operation_start(NULL, _("Scanning %s"), utf8_filename);
 	g_free (utf8_filename);
@@ -387,7 +311,7 @@ import_folders_rec(struct _import_folders_data *m, const char *filepath, const c
 
 		folder = d;
 		if (folderparent == NULL) {
-			int i;
+			gint i;
 
 			for (i=0;m->special_folders[i].orig;i++)
 				if (strcmp(m->special_folders[i].orig, folder) == 0) {
@@ -395,9 +319,9 @@ import_folders_rec(struct _import_folders_data *m, const char *filepath, const c
 					break;
 				}
 			/* FIXME: need a better way to get default store location */
-			uri = g_strdup_printf("mbox:%s/local#%s", mail_component_peek_base_directory(NULL), folder);
+			uri = g_strdup_printf("mbox:%s/local#%s", data_dir, folder);
 		} else {
-			uri = g_strdup_printf("mbox:%s/local#%s/%s", mail_component_peek_base_directory(NULL), folderparent, folder);
+			uri = g_strdup_printf("mbox:%s/local#%s/%s", data_dir, folderparent, folder);
 		}
 
 		printf("importing to uri %s\n", uri);
@@ -406,7 +330,7 @@ import_folders_rec(struct _import_folders_data *m, const char *filepath, const c
 
 		/* This little gem re-uses the stat buffer and filefull to automagically scan mozilla-format folders */
 		if (!m->elmfmt) {
-			char *tmp = g_strdup_printf("%s.sbd", filefull);
+			gchar *tmp = g_strdup_printf("%s.sbd", filefull);
 
 			g_free(filefull);
 			filefull = tmp;
@@ -445,7 +369,7 @@ import_folders_rec(struct _import_folders_data *m, const char *filepath, const c
  * standard unix directories.
  **/
 void
-mail_importer_import_folders_sync(const char *filepath, MailImporterSpecial special_folders[], int flags, CamelOperation *cancel)
+mail_importer_import_folders_sync(const gchar *filepath, MailImporterSpecial special_folders[], gint flags, CamelOperation *cancel)
 {
 	struct _import_folders_data m;
 	CamelOperation *oldcancel = NULL;
