@@ -277,12 +277,14 @@ cal_shell_view_update_actions (EShellView *shell_view)
 	ECalShellContent *cal_shell_content;
 	EShellSidebar *shell_sidebar;
 	EShellWindow *shell_window;
+	EShell *shell;
 	GnomeCalendarViewType view_type;
 	GnomeCalendar *calendar;
 	ECalendarView *view;
 	GtkAction *action;
 	GList *list, *iter;
 	gboolean sensitive;
+	gboolean visible;
 	guint32 state;
 	gint n_selected;
 
@@ -302,6 +304,23 @@ cal_shell_view_update_actions (EShellView *shell_view)
 	priv = E_CAL_SHELL_VIEW_GET_PRIVATE (shell_view);
 
 	shell_window = e_shell_view_get_shell_window (shell_view);
+	shell = e_shell_window_get_shell (shell_window);
+
+	if (e_shell_get_express_mode (shell)) {
+		GtkWidget *widget;
+
+		/* Hide the New button on the toolbar. */
+		widget = e_shell_window_get_managed_widget (
+			shell_window, "/main-toolbar");
+		widget = (GtkWidget *)gtk_toolbar_get_nth_item (
+			GTK_TOOLBAR (widget), 0);
+		gtk_widget_hide (widget);
+
+		/* Hide the main menu. */
+		widget = e_shell_window_get_managed_widget (
+			shell_window, "/main-menu");
+		gtk_widget_hide (widget);
+	}
 
 	cal_shell_content = priv->cal_shell_content;
 	calendar = e_cal_shell_content_get_calendar (cal_shell_content);
@@ -320,7 +339,7 @@ cal_shell_view_update_actions (EShellView *shell_view)
 		gboolean user_org = FALSE;
 		gboolean read_only = TRUE;
 
-		if (!event || !event->comp_data)
+		if (!is_comp_data_valid (event))
 			continue;
 
 		client = event->comp_data->client;
@@ -444,6 +463,10 @@ cal_shell_view_update_actions (EShellView *shell_view)
 	action = ACTION (EVENT_REPLY_ALL);
 	sensitive = (n_selected == 1) && is_meeting;
 	gtk_action_set_sensitive (action, sensitive);
+
+	action = ACTION (EVENT_MEETING_NEW);
+	visible = itip_addresses_get_default () != NULL;
+	gtk_action_set_visible (action, visible);
 }
 
 static void
@@ -472,6 +495,13 @@ cal_shell_view_class_init (ECalShellViewClass *class,
 	shell_view_class->new_shell_sidebar = e_cal_shell_sidebar_new;
 	shell_view_class->execute_search = cal_shell_view_execute_search;
 	shell_view_class->update_actions = cal_shell_view_update_actions;
+
+	/* XXX This is an unusual place to need an EShell instance.
+	 *     Would be cleaner to implement a method that either
+	 *     chains up or does nothing based on express mode. */
+	if (e_shell_get_express_mode (e_shell_get_default ()))
+		shell_view_class->construct_searchbar = NULL;
+
 }
 
 static void
