@@ -77,8 +77,8 @@ const gchar *	e_account_combo_box_get_active_name
 gboolean	e_account_combo_box_set_active_name
 						(EAccountComboBox *combo_box,
 						 const gchar *account_name);
-
-gint		e_account_combo_box_count_displayed_accounts (EAccountComboBox *combo_box);
+gint		e_account_combo_box_count_displayed_accounts
+						(EAccountComboBox *combo_box);
 
 G_END_DECLS
 
